@@ -309,6 +309,12 @@ class ItbTestCase(unittest.TestCase):
     def test_expected_failure(self):
         self.assertEqual(False, True)
 
+    def test_get_label(self):
+        self.assertEqual(self.engine.get_lookup_table().get_label(9), '9.')
+        self.engine.get_lookup_table().set_label(
+            9, IBus.Text.new_from_string('9'))
+        self.assertEqual(self.engine.get_lookup_table().get_label(9), '9')
+
     def test_single_char_commit_with_space(self):
         self.engine.do_process_key_event(IBus.KEY_a, 0, 0)
         self.engine.do_process_key_event(IBus.KEY_space, 0, 0)
@@ -1004,16 +1010,23 @@ class ItbTestCase(unittest.TestCase):
         self.engine.do_process_key_event(IBus.KEY_l, 0, 0)
         self.engine.do_process_key_event(IBus.KEY_e, 0, 0)
         self.assertEqual(self.engine._candidates[0][0], 'cerulean')
+        # Shift_L goes to 'capitalize':
         self.engine.do_process_key_event(IBus.KEY_Shift_L, 0, 0)
         self.engine.do_process_key_event(
             IBus.KEY_Shift_L, 0, IBus.ModifierType.RELEASE_MASK)
         self.assertEqual(self.engine._candidates[0][0], 'Cerulean')
+        # The next Shift_L goes to 'upper':
+        self.engine.do_process_key_event(IBus.KEY_Shift_L, 0, 0)
+        self.engine.do_process_key_event(
+            IBus.KEY_Shift_L, 0, IBus.ModifierType.RELEASE_MASK)
+        self.assertEqual(self.engine._candidates[0][0], 'CERULEAN')
+        # Shift_R goes back to 'capitalize':
         self.engine.do_process_key_event(IBus.KEY_Shift_R, 0, 0)
         self.engine.do_process_key_event(
             IBus.KEY_Shift_R, 0, IBus.ModifierType.RELEASE_MASK)
-        self.assertEqual(self.engine._candidates[0][0], 'CERULEAN')
+        self.assertEqual(self.engine._candidates[0][0], 'Cerulean')
         self.engine.do_process_key_event(IBus.KEY_F1, 0, 0)
-        self.assertEqual(self.engine.mock_committed_text, 'CERULEAN ')
+        self.assertEqual(self.engine.mock_committed_text, 'Cerulean ')
 
     def test_sinhala_wijesekera(self):
         self.engine.set_current_imes(
